@@ -9,12 +9,12 @@ use Carp; # only export cnv() for 'use Math::BaseCnv;' && all other stuff option
 our @EXPORT      =             qw(cnv                                                       )  ;
 our @EXPORT_OK   =             qw(    dec heX HEX b10 b64 b64sort dig diginit summ fact choo)  ;
 our %EXPORT_TAGS = ( 'all' =>[ qw(cnv dec heX HEX b10 b64 b64sort dig diginit summ fact choo) ],
-                     'heX' =>[ qw(    dec heX HEX                                           ) ],
+                     'heX' =>[ qw(cnv dec heX HEX                                           ) ],
                      'b64' =>[ qw(cnv             b10 b64 b64sort                           ) ],
                      'dig' =>[ qw(                                dig diginit               ) ],
                      'sfc' =>[ qw(                                            summ fact choo) ] );
-our $VERSION     = '1.10';our $d8VS='G7OMF3ZT';
-my $d2bs = ''; my %bs2d = (); my $nega = '';
+our $VERSION     = '1.12';our $d8VS='G7OMKBCn';
+my $d2bs='';my %bs2d=();my $nega='';
 my %digsets = (
   'usr' => [], # this will be assigned if a dig(\@newd) call is made
   'bin' => ['0', '1'],
@@ -40,13 +40,14 @@ my %digsets = (
             '_', '`', 'a'..'z', '{', '|', '}', '~'],
   'b85' => ['0'..'9', 'A'..'Z', 'a'..'z', '!', '#',  # RFC 1924 for IPv6 addresses like in Math::Base85
             '$', '%', '&', '(', ')', '*', '+', '-', ';', '<', '=', '>', '?', '@', '^', '_', '`', '{', '|', '}', '~'],
-  'b96' => [' ', '!', '"', '#', '$', '%', '&', "'",  # Base96 7-bit printable 0x20 (space) - 0x7F (tilde ~) 'ascii' from Math::Base::Convert
-            '(', ')', '*', '+', ',', '-', '.', '/', '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', ':', ';', '<', '=',
-            '>', '?', '@', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S',
-            'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '[','\\', ']', '^', '_', '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
-            'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '{', '|', '}', '~'],);
-sub bs2init { %bs2d = (); for(my $i = 0; $i < @{ $digsets{$d2bs} }; $i++) { $bs2d{${ $digsets{$d2bs} }[$i]} = $i; } } # build hash digit chars => array indices
-sub diginit { $d2bs = 'b64'; bs2init(); } # reset digit character list to initial Dflt
+  'asc' => [' ', '!', '"', '#', '$', '%', '&', "'",  # Base96 7-bit printable 0x20 (space) - 0x7F (tilde ~) 'ascii' from Math::Base::Convert
+            '(', ')', '*', '+', ',', '-', '.', '/', '0'..'9', ':', ';', '<', '=', '>', '?', '@', 'A'..'Z', '[','\\',
+            ']', '^', '_', '`', 'a'..'z', '{', '|', '}', '~'],
+  'b96' => ['0'..'9', 'A'..'Z', 'a'..'z', '.', '_',  # Base96 but starting with b64 characters
+            ' ', '!', '"', '#', '$', '%', '&', "'", '(', ')', '*', '+', ',', '-', '/', ':', ';', '<', '=', '>', '?',
+            '@', '[','\\', ']', '^', '`', '{', '|', '}', '~'],);
+sub bs2init { %bs2d=();for(my $i = 0; $i < @{ $digsets{$d2bs} }; $i++){$bs2d{${ $digsets{$d2bs} }[$i]} = $i;}} # build hash of digit chars => array indices
+sub diginit { $d2bs='b64';bs2init(); } # reset digit character list to initial default and initialize base to digit hash mapping
 sub dig { # assign a new digit character list
   return( @{ $digsets{$d2bs} } ) unless(@_);
   if(ref $_[0]) { $d2bs = 'usr'; $digsets{$d2bs} = [ @{ shift() } ]; }
@@ -116,7 +117,7 @@ Math::BaseCnv - basic functions to CoNVert between number Bases
 
 =head1 VERSION
 
-This documentation refers to version 1.10 of Math::BaseCnv, which was released on Sun Jul 24 15:03:35:29 -0500 2016.
+This documentation refers to version 1.12 of Math::BaseCnv, which was released on Sun Jul 24 20:11:12:49 -0500 2016.
 
 =head1 SYNOPSIS
 
@@ -141,8 +142,8 @@ relying only on the lovely Perl). If you would rather utilize an object syntax f
 
 The reason I created BaseCnv was that I needed a simple way to convert quickly between the 3 number bases I use most (10, 16, and 64). It turned out
 that it was trivial to handle any arbitrary number base that is represented as characters. High-bit ASCII has proven somewhat problemmatic but at least
-BaseCnv can simply and realiably convert between any possible base between 2 and 64 (or 85). I'm happy with it and employ b64() in places I probably
-shouldn't now =).
+BaseCnv can simply and reliably convert between any possible base between 2 and 64 (or 96). I'm happy with it and employ b64() in places I probably
+shouldn't now.
 
 =head1 USAGE
 
@@ -168,8 +169,8 @@ cnv() is the only function that is exported from a normal 'use Math::BaseCnv;' c
 explicitly or with the following tags:
 
   :all - every function described here
-  :heX - only dec(), heX(), and HEX()
-  :b64 - only b10(), b64(), and b64sort()
+  :heX - only cnv(), dec(), heX(), and HEX()
+  :b64 - only cnv(), b10(), b64(), and b64sort()
   :dig - only dig() and diginit()
   :sfc - only summ(), fact(), and choo()
 
@@ -229,19 +230,16 @@ following predefined digit sets:
             '$', '%', '&', '(', ')', '*', '+', '-',
             ';', '<', '=', '>', '?', '@', '^', '_',
             '`', '{', '|', '}', '~'               ],
-  'b96' => [' ', '!', '"', '#', '$', '%', '&', "'",  # Base96 7-bit printable 0x20 (space) - 0x7F
+  'asc' => [' ', '!', '"', '#', '$', '%', '&', "'",  # Base96 7-bit printable 0x20 (space) - 0x7F
             '(', ')', '*', '+', ',', '-', '.', '/',  #   (tilde ~) 'ascii' from Math::Base::Convert
-            '0', '1', '2', '3', '4', '5', '6', '7',
-            '8', '9', ':', ';', '<', '=',
-            '>', '?', '@', 'A', 'B', 'C', 'D', 'E',
-            'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
-            'N', 'O', 'P', 'Q', 'R', 'S',
-            'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '[',
-           '\\', ']', '^', '_', '`', 'a', 'b', 'c',
-            'd', 'e', 'f', 'g', 'h', 'i',
-            'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q',
-            'r', 's', 't', 'u', 'v', 'w', 'x', 'y',
-            'z', '{', '|', '}', '~'               ],
+            '0'..'9', ':', ';', '<', '=', '>', '?',
+            '@', 'A'..'Z', '[','\\', ']', '^', '_',
+            '`', 'a'..'z', '{', '|', '}', '~'     ],
+  'b96' => ['0'..'9', 'A'..'Z', 'a'..'z', '.', '_',  # Base96 but starting with b64 characters
+            ' ', '!', '"', '#', '$', '%', '&', "'",
+            '(', ')', '*', '+', ',', '-', '/', ':',
+            ';', '<', '=', '>', '?', '@', '[','\\',
+            ']', '^', '`', '{', '|', '}', '~'     ],
 
 If no \@newd list or digit set name is provided as a parameter, dig() returns the current character list. It's fine to have many more characters
 in your current digit set than will be used with your conversions (e.g., using dig('b64') works fine for any cnv() call with $from and $tobs params
@@ -270,9 +268,9 @@ A simple function to calculate a memoized BigInt function  of $ennn choose $emmm
 
 =head1 NOTES
 
-The Perl built-in hex() function takes a hex string as a parameter and returns the decimal value (FromBase = 16, ToBase = 10). This not8ion seems
+The Perl built-in hex() function takes a hex string as a parameter and returns the decimal value (FromBase = 16, ToBase = 10). This notation seems
 counter-intuitive to me since I prefer to read the code as though a hex() function will turn your parameter into hexadecimal (i.e., I think hex() should
-hexify your parameter but Perl's built-in does not.). I initially decided to invert the not8ion for my similar functions, but reconsidered the potential
+hexify your parameter but Perl's built-in does not.). I initially decided to invert the notation for my similar functions, but reconsidered the potential
 harm possible by introducing exported conflicting opposite behavior into other people's maybe crucial code, so I am falling back on unique casing with heX().
 
 My b64() function takes a decimal number as a parameter and returns the base64 equivalent (FromBase = 10, ToBase = 64) and my b10() function takes a base64
@@ -295,11 +293,17 @@ Revision history for Perl extension Math::BaseCnv:
 
 =over 2
 
+=item - 1.12 G7OMKBCn  Sun Jul 24 20:11:12:49 -0500 2016
+
+* added digit set 'b96' as a reordering of 'asc'
+
 =item - 1.10 G7OMF3ZT  Sun Jul 24 15:03:35:29 -0500 2016
 
+* added new digit sets from L<Math::Base::Convert>
+
 * switched all old hex() to distinct new heX() and updated POD to reflect
 
-* fixed META license to match POD and resolve issue: <HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=60122> (Thanks again xenoterracide.)
+* fixed META license to match POD and resolve issue: L<HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=60122> (Thanks again xenoterracide.)
 
 * removed PT from VERSION to resolve issue: L<HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=60275> (Thanks Alexandr.)
 
@@ -323,7 +327,7 @@ Revision history for Perl extension Math::BaseCnv:
 
 * added Test::Pod(::Coverage)? tests and PREREQ entries
 
-* added b85 for IPv6, gen'd META.yml (w/ newline before EOF), up'd minor ver
+* added b85 for IPv6, generated META.yml (with needed newline before EOF) and updated minor version number
 
 =item - 1.2.68J9uJQ  Sat Aug 19 09:56:19:26 2006
 
@@ -339,11 +343,11 @@ Revision history for Perl extension Math::BaseCnv:
 
 * fixed test 12 which was failing on AMD64
 
-* added Build.PL to pkg
+* added Build.PL to package
 
 =item - 1.2.54HK3pB  Sun Apr 17 20:03:51:11 2005
 
-* removed 128 digit-set since some hi-bit chars cause probs on Win32
+* removed 128 digit-set since some high-bit characters cause problems on Win32
 
 * made bin/cnv only executable to go in EXE_FILES
 
@@ -351,11 +355,11 @@ Revision history for Perl extension Math::BaseCnv:
 
 =item - 1.2.45UC8fo  Sun May 30 12:08:41:50 2004
 
-* tidied POD and upped minor version number since CPAN can't read PTVR
+* tidied POD and increased minor version number since CPAN can't read PT in VERSION
 
 =item - 1.0.44E9ljP  Wed Apr 14 09:47:45:25 2004
 
-* added test for div-by-zero error in choo()
+* added test for divide-by-zero error in choo()
 
 * added summ()
 
@@ -379,7 +383,7 @@ Revision history for Perl extension Math::BaseCnv:
 
 =item - 1.0.418BEPc  Thu Jan  8 11:14:25:38 2004
 
-* testing new e auto-gen MANIFEST(.SKIP)?
+* testing new e auto-generate MANIFEST(.SKIP)?
 
 =item - 1.0.3CNH37s  Tue Dec 23 17:03:07:54 2003
 
